\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{tesis}[2003/06/10 v2.1.4.2 Estilo para tesis (Victor Munoz)]
\newif\ifkeys\keysfalse
\newif\ifdoctorado\doctoradotrue
\DeclareOption{keys}{\keystrue}
\DeclareOption{doctorado}{\doctoradotrue}
\DeclareOption{magister}{\doctoradofalse}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions\relax
\LoadClass[oneside,12pt]{book}

% Version 2.1.4.2 2004/06/10
%   Magister en Ciencias con Mencion en Fisica 
%   -> Magister en Ciencias Fisicas
% Version 2.1.4.1 2004/06/09
%   \deactivatetilden
%   \decimalpoint
% Version 2.1.4 2004/06/02
%   \documentclass[doctorado]{tesis} (Default)
%   \documentclass[magister]{tesis}
% Version 2.1.3 2003/05/29
%   \usepackage{graphicx}
% Version 2.1.2 2003/05/14
%   \begin{aprueba}
%   \directorcomision
%   \begin{comision}
%   \miembro
%   \begin{gracias} 
% Version 2.1.1 2003/01/03
%   \makeaprueba
% Version 2.1 2002/12/04
%   \spain->\usepackage[spanish]{babel}
%   \usepackage{cite}
%   \maketapa
% Version 2.0 1999/11/16
%   Mejor modularizacion
% Version 1.0 1995/11/16
%%
%%   Modificado 16 Noviembre 1995, para que el item en el indice sea el
%%   mismo que el titulo del capitulo, y no del heading, y para que 
%%   la `i' acentuada de Capitulo quede bien en el heading. (Falta modificar 
%%   Bibliografia, y otros posibles.)
%% 
%%   Modificado desde `book.cls'.
%%
%%   Modificado para que 
%%   1) El default sea `oneside,12pt'
%%   2) Los nombres de secciones aparezcan en castellano
%%   3) La fecha aparezca en castellano
%%   4) Bibliografia aparezca bien acentuada en heading
%%   5) Los headings consten solo del numero de pagina.
%%       6) Los margenes sean: Superior = 3cm, Inferior = 3cm, 
%%                                                 Izquierdo = 4cm, Derecho = 2,5cm.
%%       7) El argumento opcional de \chapter vaya a Indice.
%%   8) Las Referencias aparezcan en Indice.
%%   9) Indice General -> Indice
%%   
%%


% En el tesis.cls original (tesiso.cls) la modificacion 7 hace que el 
% argumento opcional de \chapter vaya a Indice. Sin embargo, un argumento 
% opcional se uso solo para el Apendice. Pero los resultados de la compilacion 
% original son iguales a los de la compilacion con esta version de tesis.cls.
% Para que se hizo eso?

% En trabajo: Modificacion 8 de tesiso.cls. Lograr que Referencias aparezcan en 
% Indice

% Archivos suplementarios
\RequirePackage{epsf}
\RequirePackage[activeacute,spanish]{babel}
\RequirePackage{cite}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{txfonts}
\ifkeys\RequirePackage[notref,notcite]{showkeys}\fi
\RequirePackage[dvips]{graphicx}

% Cambios al default de spanish
\deactivatetilden
\decimalpoint


% Headings
\markboth{}{}

\addto\captionsspanish{\def\bibname{Referencia}
                                           \def\contentsname{\'Indice}}

%\newenvironment{thebibliographya}[1]{\begin{thebibliography}{#1}}%
%{\end{thebibliography}}
%\renewenvironment{thebibliography}[1]{\begin{thebibliographya}{#1}%
%\addcontentsline{toc}{chapter}{\bibname}}{\end{thebibliographya}}

% Margenes
% Superior = 3cm, Inferior = 3cm,
% Izquierdo = 4cm, Derecho = 2.5cm
\setlength{\oddsidemargin}{1.46cm}
\setlength{\textwidth}{15.1cm}
\setlength{\textheight}{21cm}

% Insercion de figuras en texto
% USO:
%       \figura{\special{isoscale ..., \the\hsize ...}}
%       \figurab{\special{isoscale ..., \the\hsize ...}}

\newcommand{\figura}[1]{
\noindent
\begin{minipage}[t]{8.5cm}
\begin{picture}(60,5)
\put(0,0){#1}
\end{picture}
\end{minipage}
}
\newcommand{\figurab}[1]{
\noindent
\begin{minipage}[t]{6cm}
\begin{picture}(60,5)
\put(0,0){#1}
\end{picture}
\end{minipage}
}

% Referenciacion en la forma: 1-5
\newcommand{\lref}[2]{\ref{#1}--\ref{#2}}

% Referenciacion en la forma:  (1)
\newcommand{\cref}[1]{(\ref{#1})}

% Referenciacion en la forma:  (1)-(5)
\newcommand{\clref}[2]{(\ref{#1})--(\ref{#2})}

%\newcommand{\cita}[1]{[\ref{#1}]}
%\newcommand{\dcita}[2]{[\ref{#1},\ref{#2}]}
%\newcommand{\lcita}[2]{[\ref{#1}--\ref{#2}]}

% Innecesario con cite.sty
%\newcommand{\lcite}[2]{[\ref{#1}--\ref{#2}]}

\newcommand{\Ref}[1]{Ref.\ \cite{#1}}
\newcommand{\dRef}[2]{Refs.\ \cite{#1},\cite{#2}}

% Innecesario con cite.sty
%\def\@bibitem#1{\item\if@filesw \immediate\write\@auxout
%       {\string\bibcite{#1}{\the\value{\@listctr}}%
%            \string\newlabel{#1}{{\the\value{\@listctr}}{\thepage}}}\fi\ignorespaces}


% ******** Comandos matematicos *********

% Parte real e imaginaria
\newcommand{\Real}{\mbox{Re }}
\newcommand{\Imag}{\mbox{Im }}

% Mayor/menor o igual y aproximado
\newfont{\msamfnt}{msam10}
\newcommand{\msam}[1]{\mbox{ \msamfnt #1}\ }
\newcommand{\simgeq}{\msam \&}
\newcommand{\simleq}{\msam .}

% ***************************************

%Abreviaciones
%\newcommand{\Cap}[1]{Cap.\ \ref{#1}}
%\newcommand{\Fig}[1]{Fig.\ \ref{#1}}
%/\newcommand{\Sec}[1]{Sec.\ \ref{#1}}

%Otros
\newcommand{\salto}{\vspace{.5cm}}


%
%      **************** Figuras ****************
%
% Enumeracion referenciable de figuras opcionalmente
% con subindices 4(a), 4(b), etc.
% USO:
%       \begin{figenum}
%       \itemfig ...
%       \labelfig{...}
%       \begin{subfigenum}
%       \itemfig ...
%       \labelfig{...}
%       \end{subfigenum}
%       \end{figenum}
%
% O BIEN (un caption global, con partes (a), (b), etc.):
%       \begin{fignum}
%       \itemfig ...
%       \labelfig{...}
%       \begin{subfignum}
%       \itemfig ...
%       \labelfig{...}
%       \end{subfignum}
%       \end{fignum}

\newcommand{\currentlabelfig}{}
\newcommand{\globallabelfig}{}
\newcommand{\currentfigmark}{}

\newcommand{\labelfig}[1]{\immediate\write\@auxout{\string
        \newlabel{#1}{{\currentlabelfig}{\thepage}}}%
\immediate\write\@auxout{\string
        \newlabel{#1global}{{\globallabelfig}{\thepage}}}}

\newcounter{uno}
\newcounter{dos}
\setcounter{uno}{0}
\setcounter{dos}{1}

\newcounter{figenum}
\newcounter{subfigenum}
\newcounter{figenumback}
\setcounter{figenum}{0}
\setcounter{figenumback}{0}

\renewcommand{\thesubfigenum}{\alph{subfigenum}}

\newcommand{\itemfig}{}
\newcommand{\itemfigback}[1]{\addtocounter{figenum}{-1}%
\setcounter{figenumback}{#1}\itemfig (Continuaci\'on.)}

\newenvironment{figenum}{\setcounter{uno}{1} \setcounter{dos}{0}
\renewcommand{\currentlabelfig}{\thefigenum}
\renewcommand{\globallabelfig}{\thefigenum}
\renewcommand{\currentfigmark}{\thefigenum}
\renewcommand{\itemfig}{\addtocounter{figenum}{\value{uno}}%
\addtocounter{subfigenum}{\value{dos}}%
\item Fig.\ \currentfigmark.\ 
}
\begin{enumerate}}{\renewcommand{\currentlabelfig}{}%
\renewcommand{\globallabelfig}{}%
\renewcommand{\currentfigmark}{}\end{enumerate}}

\newenvironment{subfigenum}{\addtocounter{figenum}{1}
\setcounter{uno}{0}\setcounter{dos}{1}
\renewcommand{\currentlabelfig}{\thefigenum(\thesubfigenum)}
\renewcommand{\currentfigmark}{\thefigenum(\thesubfigenum)}
\setcounter{subfigenum}{0}}{\setcounter{uno}{1}\setcounter{dos}{0}
\renewcommand{\currentlabelfig}{\thefigenum}
\renewcommand{\currentfigmark}{\thefigenum}}


\newenvironment{fignum}{\setcounter{uno}{1} \setcounter{dos}{0}
\renewcommand{\currentlabelfig}{\thefigenum}
\renewcommand{\globallabelfig}{\thefigenum}
\renewcommand{\currentfigmark}{\thefigenum}
\renewcommand{\itemfig}{\addtocounter{figenum}{\value{uno}}%
\addtocounter{subfigenum}{\value{dos}}%
\item Fig.\ \currentfigmark.\ 
}
\begin{enumerate}}{\renewcommand{\currentlabelfig}{}%
\renewcommand{\globallabelfig}{}%
\renewcommand{\currentfigmark}{}\end{enumerate}
}

\newenvironment{subfignum}{\setcounter{uno}{0}\setcounter{dos}{1}%
\renewcommand{\currentlabelfig}{\thefigenum(\thesubfigenum)}%
\renewcommand{\currentfigmark}{(\thesubfigenum)}%
\renewcommand{\itemfig}{\addtocounter{figenum}{\value{uno}}%
\addtocounter{subfigenum}{\value{dos}}%
\currentfigmark~}%
\setcounter{subfigenum}{0}}{\setcounter{uno}{1}\setcounter{dos}{0}%
\renewcommand{\currentlabelfig}{\thefigenum}%
\renewcommand{\currentfigmark}{\thefigenum}%
\renewcommand{\itemfig}{\addtocounter{figenum}{\value{uno}}%
\addtocounter{subfigenum}{\value{dos}}%
\item Fig.\ \currentfigmark.\ }%
}

% Figuras en texto, mezclando el figure de LaTeX y el fignum de tesis.cls

\newenvironment{figtxt}{\setcounter{uno}{1} \setcounter{dos}{0}
\renewcommand{\currentlabelfig}{\thefigenum}
\renewcommand{\globallabelfig}{\thefigenum}
\renewcommand{\currentfigmark}{\thefigenum}
\renewcommand{\itemfig}{\addtocounter{figenum}{\value{uno}}%
\addtocounter{subfigenum}{\value{dos}}%
\vspace*{-1.5cm}%
\item[] Fig.\ \currentfigmark.\ }
\begin{list}{}%
{\setlength{\leftmargin}{1.5em}\setlength{\rightmargin}{\leftmargin}}}%
{\renewcommand{\currentlabelfig}{}%
\renewcommand{\globallabelfig}{}%
\renewcommand{\currentfigmark}{}\end{list}
}

\newenvironment{subfigtxt}{\setcounter{uno}{0}\setcounter{dos}{1}%
\renewcommand{\currentlabelfig}{\thefigenum(\thesubfigenum)}%
\renewcommand{\currentfigmark}{(\thesubfigenum)}%
\renewcommand{\itemfig}{\addtocounter{figenum}{\value{uno}}%
\addtocounter{subfigenum}{\value{dos}}%
\currentfigmark~}%
\setcounter{subfigenum}{\value{figenumback}}%
\setcounter{figenumback}{0}}{\setcounter{uno}{1}\setcounter{dos}{0}%
\renewcommand{\currentlabelfig}{\thefigenum}%
\renewcommand{\currentfigmark}{\thefigenum}%
\renewcommand{\itemfig}{\addtocounter{figenum}{\value{uno}}%
\addtocounter{subfigenum}{\value{dos}}%
\item[] Fig.\ \currentfigmark.\ }%
}

\newenvironment{fig}[1][tbp]{\begin{figure}[#1]
\baselineskip 24pt}{\end{figure}}


% Referencias
%       [1] ...
%       [2] ...

\newenvironment{references}{\newpage\noindent {\bf References}
\begin{list}{[\arabic{enumi}]}{\usecounter{enumi}}}{\end{list}}

% Figuras al final del paper, con rotulo NombreAutor--Revista
% USO:
%       \figpaper{1.hgl}{fig1}

\newcommand{\figpaper}[2]{\newpage\pagestyle{empty}\par
\hspace*{-1.7cm}
\special{isoscale #1, \the\hsize 15cm}
\vspace*{14cm}\par
\begin{center}Fig.\ \ref{#2}\end{center}\par
\vfill\hfill Mu\~noz \hspace{.7cm} Phys.\ Rev.\ E
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Todo esto era para figuras en paper, que aca no tiene sentido
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Figuras PostScript al final del paper, 
%% USO:
%%       \figpspaper{1.eps}{fig1}
%%


%% Pagina de figuras al final del paper

%\newcommand{\figtext}[1]{\par
%\vfill
%%\begin{center}Fig.\ #1\end{center}%\par
%\hfill Fig.\ #1 \hfill{} \newpage}

%\newenvironment{figpage}{\newpage\addtolength{\topmargin}{1.5cm}}%
%{\addtolength{\topmargin}{-1.5cm}}

%%\newenvironment{figpage}{\newpage\pagestyle{empty}}{}

%% Figuras Postcript al final del paper, sin rotulo NombreAutor--Revista,
%% y agrupadas en paneles.
%% USO:
%%   \figpspaper...{1.eps}{fig1}
%%   El comando tiene un subindice, que indica el numero de figuras en
%% la pagina, en numeros romanos, minuscula.
%%
%% Tamano pagina total usable: (17,23)

%\newcommand{\figpspaper}[2]{\newpage\par
%\hspace*{-1.7cm}
%\epsfxsize=16cm
%\epsfbox{#1}
%\figtext{\ref{#2}}%
%%\par
%%\begin{center}Fig.\ \ref{#2}\end{center}\par
%%\vfill\hfill Mu\~noz \hspace{.7cm} Phys.\ Rev.\ E
%}

%\newcommand{\figpspaperii}[3]{%
%\setlength{\unitlength}{1cm}%
%\begin{picture}(17,16)%
%\put(1,8.9){\epsfxsize=10.5cm\epsfbox{#1}}%
%\put(1,1.5){\epsfxsize=10.5cm\epsfbox{#2}}%
%\end{picture}%
%\figtext{\ref{#3global}}%
%}

%\newcommand{\figpspaperiii}[4]{%
%\vspace*{1cm}%
%\setlength{\unitlength}{1cm}%
%\begin{picture}(17,16)%
%\put(1,13.8){\epsfxsize=10.5cm\epsfbox{#1}}%
%\put(1,6.4){\epsfxsize=10.5cm\epsfbox{#2}}%
%\put(1,-1){\epsfxsize=10.5cm\epsfbox{#3}}%
%\end{picture}%
%\par%
%\figtext{\ref{#4global}}%
%}

%\newcommand{\figpspaperiv}[5]{%
%\hspace*{-5.5cm}%
%\setlength{\unitlength}{1cm}%
%\begin{picture}(17,16)%
%\put(1.9,8.9){\epsfxsize=10.5cm\epsfbox{#1}}%
%\put(11.1,8.9){\epsfxsize=10.5cm\epsfbox{#2}}%
%\put(1.9,1.5){\epsfxsize=10.5cm\epsfbox{#3}}%
%\put(11.1,1.5){\epsfxsize=10.5cm\epsfbox{#4}}%
%\end{picture}%
%\par%
%\figtext{\ref{#5global}}%
%}

% Figuras Postcript en el texto, agrupadas en paneles.
% USO:
%   \figps...{1.eps}{fig1}
%   El comando tiene un subindice, que indica el numero de figuras en
% la pagina, en numeros romanos, minuscula.
%
% Tamano pagina total usable: %(17,23)

\newcommand{\figps}[1]{%
\setlength{\unitlength}{1cm}%
\begin{picture}(16,5)(3.3,3)%
\put(3,0){\epsfxsize=15cm\epsfbox{#1}}%
\end{picture}%
}

\newcommand{\figpsii}[2]{%
\setlength{\unitlength}{1cm}%
\begin{picture}(16,7.5)(2.3,0)%
\put(0,0){\epsfxsize=10.5cm\epsfbox{#1}}%
\put(9.5,0){\epsfxsize=10.5cm\epsfbox{#2}}%
\end{picture}%
}

\newcommand{\figpsiii}[3]{%
\setlength{\unitlength}{1cm}%
\begin{picture}(16,13.5)(2.3,0)%
\put(0,7.5){\epsfxsize=10.5cm\epsfbox{#1}}%
\put(9.5,7.5){\epsfxsize=10.5cm\epsfbox{#2}}%
\put(4.75,0){\epsfxsize=10.5cm\epsfbox{#3}}%
\end{picture}%
}

\newcommand{\figpsiv}[4]{%
\setlength{\unitlength}{1cm}%
\begin{picture}(16,13.5)(2.3,0)%
\put(0,7.5){\epsfxsize=10.5cm\epsfbox{#1}}%
\put(9.5,7.5){\epsfxsize=10.5cm\epsfbox{#2}}%
\put(0,0){\epsfxsize=10.5cm\epsfbox{#3}}%
\put(9.5,0){\epsfxsize=10.5cm\epsfbox{#4}}%
\end{picture}%
}


% Pagina de titulo

%  El resultado no es exactamente el mismo que con el codigo
% original (las lineas del titulo quedan mas separadas), 
% pero no logramos arreglarlo
%
% Codigo original:
%
%{\large 
%
%\begin{center}
%{\LARGE \bf Decaimientos param\'etricos de ondas electromagn\'eticas en
%plasmas de electrones y positrones}
%\end{center}
%
%\vspace{1cm}
%\begin{center}
%Tesis\\ 
%entregada a la\\
%Universidad de Chile\\
%en cumplimiento parcial de los requisitos\\
%para optar al grado de\\
%Doctor en Ciencias con menci\'on en F\'{\i}sica\\
%Facultad de Ciencias\\[2cm]
%por\\[1.5cm]
%{\bf V\'{\i}ctor Hugo Mu\~noz G\'alvez}\\[1.5cm]
%Abril, 1998
%\end{center}

%\vspace{1cm}
%\begin{center}
%Director de Tesis: {\bf Dr. Luis Gomberoff Jaikles}
%\end{center}
%}

\def\@title{} \def\@autor{} \def\@fecha{} \def\@director{}

\def\titulo#1{\gdef\@title{\begin{center}{\LARGE\bf#1}%
\end{center}}}

\def\autor#1{\gdef\@autor{{\bfseries #1}}}

\def\fecha#1#2#3{\gdef\@diaexamen{#1}\gdef\@mesexamen{#2}%
\gdef\@annoexamen{#3}\gdef\@fecha{#2, #3}}

\def\director#1{\gdef\@director{{\bfseries #1}}}

\newsavebox{\GradoTesis}
\newsavebox{\Gradotesis}
\newsavebox{\GradoOtorgado}
\newsavebox{\GradoOtorgadoTapa}

\ifdoctorado\savebox{\GradoTesis}{DOCTORADO}
            \savebox{\Gradotesis}{Doctorado}
            \savebox{\GradoOtorgado}{Doctor en Ciencias con menci\'on
              en F\'{\i}sica}
            \savebox{\GradoOtorgadoTapa}{\large Doctor en Ciencias 
              con menci\'on en F\'{\i}sica}
  \else\savebox{\GradoTesis}{MAG\'ISTER}
       \savebox{\Gradotesis}{Mag\'{\i}ster}
       \savebox{\GradoOtorgado}{Mag\'{\i}ster en Ciencias F\'{\i}sicas}
       \savebox{\GradoOtorgadoTapa}{\large Mag\'{\i}ster en Ciencias 
         F\'{\i}sicas}
\fi

\newcommand{\maketapa}{\@title\par\vspace{1cm}{\large\begin{center}%
Tesis\\ 
entregada a la\\
Universidad de Chile\\
en cumplimiento parcial de los requisitos\\
para optar al grado de\\
\usebox{\GradoOtorgadoTapa}\\
Facultad de Ciencias\\[2cm]
por\\[1.5cm]
\@autor\\[1.5cm]
\@fecha
\end{center}\par
\vspace{1cm}
\begin{center}
Director de Tesis: \@director
\end{center}
}}

% Pagina de aprobacion

%\begin{center}
%FACULTAD DE CIENCIAS\\
%UNIVERSIDAD DE CHILE
%\end{center}
%
%\vspace{.5cm}
%
%\begin{center}
%INFORME DE APROBACI\'ON\\
%TESIS DE DOCTORADO
%\end{center}
%
%\vspace{1cm}
%
%Se informa a la Escuela de Postgrado de la Facultad de Ciencias que
%la Tesis de Doctorado presentada por el candidato
%
%\begin{center}
%{\bf V\'{\i}ctor Hugo Mu\~noz G\'alvez}
%\end{center}
%
%\noindent
%ha sido aprobada por la Comisi\'on de Evaluaci\'on de la Tesis como
%requisito para optar al grado de Doctor en Ciencias con menci\'on en
%F\'{\i}sica, en el examen de Defensa de Tesis rendido el d\'{\i}a 7
%de Abril de 1998. 
%
%\vspace{1cm}
%\noindent
%\begin{tabular}{l@{\hspace{1cm}}l}
%{\bf Director de Tesis}\\[.5cm]
%Dr.\ Luis Gomberoff&\rule{6cm}{\arrayrulewidth}\\[.7cm]
%{\bf Comisi\'on de Evaluaci\'on de la Tesis}\\[.5cm]
%Dr.\ Mario Molina&\rule{6cm}{\arrayrulewidth}\\[.5cm]
%Dr.\ Miguel Orszag&\rule{6cm}{\arrayrulewidth}\\[.5cm]
%Dr.\ Jaime R\"ossler (Presidente)&\rule{6cm}{\arrayrulewidth}\\[.5cm]
%Dr.\ Enrique Tirapegui&\rule{6cm}{\arrayrulewidth}
%\end{tabular}

\newcommand{\makeaprueba}{
\begin{center}
FACULTAD DE CIENCIAS FISICAS Y MATEMATICAS\\
UNIVERSIDAD DE CHILE
\end{center}\par
\vspace{.5cm}\par
\begin{center}
INFORME DE APROBACI\'ON\\
TESIS DE \usebox{\GradoTesis}
\end{center}\par
\vspace{1cm}\par
Se informa a la Escuela de Postgrado de la Facultad de Ciencias que
la Tesis de \usebox{\Gradotesis} presentada por el candidato\par
\begin{center}\@autor\end{center}\par\noindent
ha sido aprobada por la Comisi\'on de Evaluaci\'on de la Tesis como
requisito para optar al grado de \usebox{\GradoOtorgado}, en el examen
de Defensa de Tesis rendido el d\'{\i}a  
\@diaexamen\ de \@mesexamen\ de \@annoexamen.\par
}

\newcommand{\directorcomision}[1]{
\vspace{1cm}\noindent
%\begin{tabular}{l@{\hspace{1cm}}l}
{\bf Director de Tesis}\\[.5cm]
#1\hfill\rule{6cm}{\arrayrulewidth}\\[.7cm]}


\newcommand{\miembro}[1]{\noindent #1 
\hfill \rule{6cm}{\arrayrulewidth}\\[.3cm]}

\newenvironment{comision}{\noindent
{\bf Comisi\'on de Evaluaci\'on de la Tesis}\\[.3cm]}%
{}

\newenvironment{aprueba}{\makeaprueba}{}

% Pagina de gracias

%\begin{center}
%{\Large AGRADECIMIENTOS}
%\end{center}
%Deseo agradecer \ldots

\newenvironment{gracias}{\begin{center}
{\Large AGRADECIMIENTOS}
\end{center}}{}

% Pagina de abstract

%\begin{center}
%{\Large RESUMEN}
%\end{center}
%
% ...
%\begin{center}
%{\Large ABSTRACT}
%\end{center}
%
% ...

\newcommand{\resumenCastellano}[1]{%
  \begin{center}
    {\Large RESUMEN}
  \end{center}

#1
}

\newcommand{\resumenIngles}[1]{%
  \begin{center}
    {\Large ABSTRACT}
  \end{center}

#1
}



    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %  Prints your review date and 'Draft Version' (From Josullvn, CS, CMU)
 \newcommand{\reviewtimetoday}[2]{\special{!userdict begin
     /bop-hook{gsave 530 750 translate -45 rotate
     /Times-Roman findfont 12 scalefont setfont 0 0   moveto (#1) show
     0 -12 moveto (#2) show grestore}def end}}
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%






\endinput
%% 
%% End of file `tesis.cls'.


